import os
import sys
import shutil


PIVY_HEADER = """\
#ifdef __PIVY__
%%include %s
#endif

"""


def swigify_header(header_file, include_file):
    sys.stdout.write("create swigified header: " + header_file + "\n")

    fd = open(header_file, "r+")
    contents = fd.readlines()

    ins_line_nr = -1
    for line in contents:
        ins_line_nr += 1
        if line.find("#include ") != -1:
            break

    if ins_line_nr != -1:
        contents.insert(ins_line_nr, PIVY_HEADER % (include_file))
        fd.seek(0)
        fd.writelines(contents)
    else:
        print("[failed]")
        sys.exit(1)
    fd.close


def copy_and_swigify_header(interface_dir, include_dir, fname):
    """Copy the header file to the local include directory. Add an
    #include line at the beginning for the SWIG interface file..."""

    if fname.endswith(".i"):  # consider ".i" files
        fname_h = fname[:-2] + ".h"  # corresponding ".h" file
        from_file = os.path.join(include_dir, fname_h)
        to_file = os.path.join(interface_dir, fname_h)

    elif fname.endswith(".fix"):  # just drop the suffix
        # fixes for SWIG 1.3.21 and upwards
        # (mostly workarounding swig's preprocessor "function like macros"
        # preprocessor bug when no parameters are provided which then results
        # in no constructors being created in the wrapper)
        fname_nosuffix = fname[:-4]
        from_file = os.path.join(interface_dir, fname)
        to_file = os.path.join(interface_dir, fname_nosuffix)

    elif sys.platform == "win32" and fname.endswith(".win32"):  # just drop the suffix
        # had to introduce this because windows is a piece of crap
        fname_nosuffix = fname[:-6]
        from_file = os.path.join(interface_dir, fname)
        to_file = os.path.join(interface_dir, fname_nosuffix)

    else:  # ignore other extensions
        return

    if not os.path.isfile(os.path.join(from_file)):
        return

    # copy
    shutil.copyfile(from_file, to_file)

    # and swigify
    if fname.endswith(".i"):  # consider ".i" files
        swigify_header(to_file, fname)


def swigify(interface_dir, include_dir, component="Inventor"):
    """Prepare header files for SWIG"""

    # find files within interface_dir/component
    interface_walker = os.walk(os.path.join(interface_dir, component))
    for dirpath, _, fnames in interface_walker:
        for fname in fnames:
            # only the filename relative to below interface_dir is needed
            relative_fname = os.path.join(dirpath[1+len(interface_dir):], fname)
            copy_and_swigify_header(interface_dir, include_dir, relative_fname)


if __name__ == "__main__":
    swigify(sys.argv[1], sys.argv[2])



#!/usr/bin/env python

###
# Copyright (c) 2002-2007 Systems in Motion
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#

###
# This is an example from the Inventor Mentor
# chapter 13, example 2.
#
# Global fields.
# A digital clock is implemented by connecting the realTime
# global field to a Text3 string.
#

import sys

from pivy.coin import *
from pivy.sogui import *

def main():
    # Initialize Inventor and Qt
    myWindow = SoGui.init(sys.argv[0])  
    if myWindow == None: sys.exit(1)     

    root = SoSeparator()
   
    # Add a camera, light, and material
    myCamera = SoPerspectiveCamera()
    root.addChild(myCamera)
    root.addChild(SoDirectionalLight())
    myMaterial = SoMaterial()
    myMaterial.diffuseColor = (1.0, 0.0, 0.0)   
    root.addChild(myMaterial)

    # Create a Text3 object, and connect to the realTime field
    myText = SoText3()
    root.addChild(myText)
    myText.string.connectFrom(SoDB.getGlobalField("realTime"))

    myRenderArea = SoGuiRenderArea(myWindow)
    myCamera.viewAll(root, myRenderArea.getViewportRegion())
    myRenderArea.setSceneGraph(root)
    myRenderArea.setTitle("Date & Time")
    myRenderArea.show()

    SoGui.show(myWindow)
    SoGui.mainLoop()

if __name__ == "__main__":
    main()
